@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2017 David R. MacIver
+# Most of this work is copyright (C) 2013-2018 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -32,7 +32,7 @@ from hypothesis.internal.compat import text_type, integer_types
 
 def type_sorting_key(t):
     """Minimise to None, then non-container types, then container types."""
-    if t is None or t is type(None):
+    if t is None or t is type(None):  # noqa: E721
         return -1
     return issubclass(t, collections.abc.Container)
 
